# Installation

Currently, only Docker-based setup is fully supported and tested.

Local installation should be as straightforward as following the Dockerfile instructions. However, it is yet to be explored!

- [Installation (Docker)](./docker.md)
